"""
Type annotations for devicefarm service literal definitions.

[Open documentation](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_devicefarm/literals/)

Usage::

    ```python
    from types_aiobotocore_devicefarm.literals import ArtifactCategoryType

    data: ArtifactCategoryType = "FILE"
    ```
"""
import sys

if sys.version_info >= (3, 9):
    from typing import Literal
else:
    from typing_extensions import Literal


__all__ = (
    "ArtifactCategoryType",
    "ArtifactTypeType",
    "BillingMethodType",
    "CurrencyCodeType",
    "DeviceAttributeType",
    "DeviceAvailabilityType",
    "DeviceFilterAttributeType",
    "DeviceFormFactorType",
    "DevicePlatformType",
    "DevicePoolTypeType",
    "ExecutionResultCodeType",
    "ExecutionResultType",
    "ExecutionStatusType",
    "GetOfferingStatusPaginatorName",
    "InstanceStatusType",
    "InteractionModeType",
    "ListArtifactsPaginatorName",
    "ListDeviceInstancesPaginatorName",
    "ListDevicePoolsPaginatorName",
    "ListDevicesPaginatorName",
    "ListInstanceProfilesPaginatorName",
    "ListJobsPaginatorName",
    "ListNetworkProfilesPaginatorName",
    "ListOfferingPromotionsPaginatorName",
    "ListOfferingTransactionsPaginatorName",
    "ListOfferingsPaginatorName",
    "ListProjectsPaginatorName",
    "ListRemoteAccessSessionsPaginatorName",
    "ListRunsPaginatorName",
    "ListSamplesPaginatorName",
    "ListSuitesPaginatorName",
    "ListTestsPaginatorName",
    "ListUniqueProblemsPaginatorName",
    "ListUploadsPaginatorName",
    "ListVPCEConfigurationsPaginatorName",
    "NetworkProfileTypeType",
    "OfferingTransactionTypeType",
    "OfferingTypeType",
    "RecurringChargeFrequencyType",
    "RuleOperatorType",
    "SampleTypeType",
    "TestGridSessionArtifactCategoryType",
    "TestGridSessionArtifactTypeType",
    "TestGridSessionStatusType",
    "TestTypeType",
    "UploadCategoryType",
    "UploadStatusType",
    "UploadTypeType",
    "DeviceFarmServiceName",
    "ServiceName",
    "ResourceServiceName",
    "PaginatorName",
    "RegionName",
)


ArtifactCategoryType = Literal["FILE", "LOG", "SCREENSHOT"]
ArtifactTypeType = Literal[
    "APPIUM_JAVA_OUTPUT",
    "APPIUM_JAVA_XML_OUTPUT",
    "APPIUM_PYTHON_OUTPUT",
    "APPIUM_PYTHON_XML_OUTPUT",
    "APPIUM_SERVER_OUTPUT",
    "APPLICATION_CRASH_REPORT",
    "AUTOMATION_OUTPUT",
    "CALABASH_JAVA_XML_OUTPUT",
    "CALABASH_JSON_OUTPUT",
    "CALABASH_PRETTY_OUTPUT",
    "CALABASH_STANDARD_OUTPUT",
    "CUSTOMER_ARTIFACT",
    "CUSTOMER_ARTIFACT_LOG",
    "DEVICE_LOG",
    "EXERCISER_MONKEY_OUTPUT",
    "EXPLORER_EVENT_LOG",
    "EXPLORER_SUMMARY_LOG",
    "INSTRUMENTATION_OUTPUT",
    "MESSAGE_LOG",
    "RESULT_LOG",
    "SCREENSHOT",
    "SERVICE_LOG",
    "TESTSPEC_OUTPUT",
    "UNKNOWN",
    "VIDEO",
    "VIDEO_LOG",
    "WEBKIT_LOG",
    "XCTEST_LOG",
]
BillingMethodType = Literal["METERED", "UNMETERED"]
CurrencyCodeType = Literal["USD"]
DeviceAttributeType = Literal[
    "APPIUM_VERSION",
    "ARN",
    "AVAILABILITY",
    "FLEET_TYPE",
    "FORM_FACTOR",
    "INSTANCE_ARN",
    "INSTANCE_LABELS",
    "MANUFACTURER",
    "MODEL",
    "OS_VERSION",
    "PLATFORM",
    "REMOTE_ACCESS_ENABLED",
    "REMOTE_DEBUG_ENABLED",
]
DeviceAvailabilityType = Literal["AVAILABLE", "BUSY", "HIGHLY_AVAILABLE", "TEMPORARY_NOT_AVAILABLE"]
DeviceFilterAttributeType = Literal[
    "ARN",
    "AVAILABILITY",
    "FLEET_TYPE",
    "FORM_FACTOR",
    "INSTANCE_ARN",
    "INSTANCE_LABELS",
    "MANUFACTURER",
    "MODEL",
    "OS_VERSION",
    "PLATFORM",
    "REMOTE_ACCESS_ENABLED",
    "REMOTE_DEBUG_ENABLED",
]
DeviceFormFactorType = Literal["PHONE", "TABLET"]
DevicePlatformType = Literal["ANDROID", "IOS"]
DevicePoolTypeType = Literal["CURATED", "PRIVATE"]
ExecutionResultCodeType = Literal["PARSING_FAILED", "VPC_ENDPOINT_SETUP_FAILED"]
ExecutionResultType = Literal[
    "ERRORED", "FAILED", "PASSED", "PENDING", "SKIPPED", "STOPPED", "WARNED"
]
ExecutionStatusType = Literal[
    "COMPLETED",
    "PENDING",
    "PENDING_CONCURRENCY",
    "PENDING_DEVICE",
    "PREPARING",
    "PROCESSING",
    "RUNNING",
    "SCHEDULING",
    "STOPPING",
]
GetOfferingStatusPaginatorName = Literal["get_offering_status"]
InstanceStatusType = Literal["AVAILABLE", "IN_USE", "NOT_AVAILABLE", "PREPARING"]
InteractionModeType = Literal["INTERACTIVE", "NO_VIDEO", "VIDEO_ONLY"]
ListArtifactsPaginatorName = Literal["list_artifacts"]
ListDeviceInstancesPaginatorName = Literal["list_device_instances"]
ListDevicePoolsPaginatorName = Literal["list_device_pools"]
ListDevicesPaginatorName = Literal["list_devices"]
ListInstanceProfilesPaginatorName = Literal["list_instance_profiles"]
ListJobsPaginatorName = Literal["list_jobs"]
ListNetworkProfilesPaginatorName = Literal["list_network_profiles"]
ListOfferingPromotionsPaginatorName = Literal["list_offering_promotions"]
ListOfferingTransactionsPaginatorName = Literal["list_offering_transactions"]
ListOfferingsPaginatorName = Literal["list_offerings"]
ListProjectsPaginatorName = Literal["list_projects"]
ListRemoteAccessSessionsPaginatorName = Literal["list_remote_access_sessions"]
ListRunsPaginatorName = Literal["list_runs"]
ListSamplesPaginatorName = Literal["list_samples"]
ListSuitesPaginatorName = Literal["list_suites"]
ListTestsPaginatorName = Literal["list_tests"]
ListUniqueProblemsPaginatorName = Literal["list_unique_problems"]
ListUploadsPaginatorName = Literal["list_uploads"]
ListVPCEConfigurationsPaginatorName = Literal["list_vpce_configurations"]
NetworkProfileTypeType = Literal["CURATED", "PRIVATE"]
OfferingTransactionTypeType = Literal["PURCHASE", "RENEW", "SYSTEM"]
OfferingTypeType = Literal["RECURRING"]
RecurringChargeFrequencyType = Literal["MONTHLY"]
RuleOperatorType = Literal[
    "CONTAINS",
    "EQUALS",
    "GREATER_THAN",
    "GREATER_THAN_OR_EQUALS",
    "IN",
    "LESS_THAN",
    "LESS_THAN_OR_EQUALS",
    "NOT_IN",
]
SampleTypeType = Literal[
    "CPU",
    "MEMORY",
    "NATIVE_AVG_DRAWTIME",
    "NATIVE_FPS",
    "NATIVE_FRAMES",
    "NATIVE_MAX_DRAWTIME",
    "NATIVE_MIN_DRAWTIME",
    "OPENGL_AVG_DRAWTIME",
    "OPENGL_FPS",
    "OPENGL_FRAMES",
    "OPENGL_MAX_DRAWTIME",
    "OPENGL_MIN_DRAWTIME",
    "RX",
    "RX_RATE",
    "THREADS",
    "TX",
    "TX_RATE",
]
TestGridSessionArtifactCategoryType = Literal["LOG", "VIDEO"]
TestGridSessionArtifactTypeType = Literal["SELENIUM_LOG", "UNKNOWN", "VIDEO"]
TestGridSessionStatusType = Literal["ACTIVE", "CLOSED", "ERRORED"]
TestTypeType = Literal[
    "APPIUM_JAVA_JUNIT",
    "APPIUM_JAVA_TESTNG",
    "APPIUM_NODE",
    "APPIUM_PYTHON",
    "APPIUM_RUBY",
    "APPIUM_WEB_JAVA_JUNIT",
    "APPIUM_WEB_JAVA_TESTNG",
    "APPIUM_WEB_NODE",
    "APPIUM_WEB_PYTHON",
    "APPIUM_WEB_RUBY",
    "BUILTIN_EXPLORER",
    "BUILTIN_FUZZ",
    "CALABASH",
    "INSTRUMENTATION",
    "REMOTE_ACCESS_RECORD",
    "REMOTE_ACCESS_REPLAY",
    "UIAUTOMATION",
    "UIAUTOMATOR",
    "WEB_PERFORMANCE_PROFILE",
    "XCTEST",
    "XCTEST_UI",
]
UploadCategoryType = Literal["CURATED", "PRIVATE"]
UploadStatusType = Literal["FAILED", "INITIALIZED", "PROCESSING", "SUCCEEDED"]
UploadTypeType = Literal[
    "ANDROID_APP",
    "APPIUM_JAVA_JUNIT_TEST_PACKAGE",
    "APPIUM_JAVA_JUNIT_TEST_SPEC",
    "APPIUM_JAVA_TESTNG_TEST_PACKAGE",
    "APPIUM_JAVA_TESTNG_TEST_SPEC",
    "APPIUM_NODE_TEST_PACKAGE",
    "APPIUM_NODE_TEST_SPEC",
    "APPIUM_PYTHON_TEST_PACKAGE",
    "APPIUM_PYTHON_TEST_SPEC",
    "APPIUM_RUBY_TEST_PACKAGE",
    "APPIUM_RUBY_TEST_SPEC",
    "APPIUM_WEB_JAVA_JUNIT_TEST_PACKAGE",
    "APPIUM_WEB_JAVA_JUNIT_TEST_SPEC",
    "APPIUM_WEB_JAVA_TESTNG_TEST_PACKAGE",
    "APPIUM_WEB_JAVA_TESTNG_TEST_SPEC",
    "APPIUM_WEB_NODE_TEST_PACKAGE",
    "APPIUM_WEB_NODE_TEST_SPEC",
    "APPIUM_WEB_PYTHON_TEST_PACKAGE",
    "APPIUM_WEB_PYTHON_TEST_SPEC",
    "APPIUM_WEB_RUBY_TEST_PACKAGE",
    "APPIUM_WEB_RUBY_TEST_SPEC",
    "CALABASH_TEST_PACKAGE",
    "EXTERNAL_DATA",
    "INSTRUMENTATION_TEST_PACKAGE",
    "INSTRUMENTATION_TEST_SPEC",
    "IOS_APP",
    "UIAUTOMATION_TEST_PACKAGE",
    "UIAUTOMATOR_TEST_PACKAGE",
    "WEB_APP",
    "XCTEST_TEST_PACKAGE",
    "XCTEST_UI_TEST_PACKAGE",
    "XCTEST_UI_TEST_SPEC",
]
DeviceFarmServiceName = Literal["devicefarm"]
ServiceName = Literal[
    "accessanalyzer",
    "account",
    "acm",
    "acm-pca",
    "alexaforbusiness",
    "amp",
    "amplify",
    "amplifybackend",
    "amplifyuibuilder",
    "apigateway",
    "apigatewaymanagementapi",
    "apigatewayv2",
    "appconfig",
    "appconfigdata",
    "appflow",
    "appintegrations",
    "application-autoscaling",
    "application-insights",
    "applicationcostprofiler",
    "appmesh",
    "apprunner",
    "appstream",
    "appsync",
    "athena",
    "auditmanager",
    "autoscaling",
    "autoscaling-plans",
    "backup",
    "backup-gateway",
    "batch",
    "billingconductor",
    "braket",
    "budgets",
    "ce",
    "chime",
    "chime-sdk-identity",
    "chime-sdk-meetings",
    "chime-sdk-messaging",
    "cloud9",
    "cloudcontrol",
    "clouddirectory",
    "cloudformation",
    "cloudfront",
    "cloudhsm",
    "cloudhsmv2",
    "cloudsearch",
    "cloudsearchdomain",
    "cloudtrail",
    "cloudwatch",
    "codeartifact",
    "codebuild",
    "codecommit",
    "codedeploy",
    "codeguru-reviewer",
    "codeguruprofiler",
    "codepipeline",
    "codestar",
    "codestar-connections",
    "codestar-notifications",
    "cognito-identity",
    "cognito-idp",
    "cognito-sync",
    "comprehend",
    "comprehendmedical",
    "compute-optimizer",
    "config",
    "connect",
    "connect-contact-lens",
    "connectparticipant",
    "cur",
    "customer-profiles",
    "databrew",
    "dataexchange",
    "datapipeline",
    "datasync",
    "dax",
    "detective",
    "devicefarm",
    "devops-guru",
    "directconnect",
    "discovery",
    "dlm",
    "dms",
    "docdb",
    "drs",
    "ds",
    "dynamodb",
    "dynamodbstreams",
    "ebs",
    "ec2",
    "ec2-instance-connect",
    "ecr",
    "ecr-public",
    "ecs",
    "efs",
    "eks",
    "elastic-inference",
    "elasticache",
    "elasticbeanstalk",
    "elastictranscoder",
    "elb",
    "elbv2",
    "emr",
    "emr-containers",
    "es",
    "events",
    "evidently",
    "finspace",
    "finspace-data",
    "firehose",
    "fis",
    "fms",
    "forecast",
    "forecastquery",
    "frauddetector",
    "fsx",
    "gamelift",
    "glacier",
    "globalaccelerator",
    "glue",
    "grafana",
    "greengrass",
    "greengrassv2",
    "groundstation",
    "guardduty",
    "health",
    "healthlake",
    "honeycode",
    "iam",
    "identitystore",
    "imagebuilder",
    "importexport",
    "inspector",
    "inspector2",
    "iot",
    "iot-data",
    "iot-jobs-data",
    "iot1click-devices",
    "iot1click-projects",
    "iotanalytics",
    "iotdeviceadvisor",
    "iotevents",
    "iotevents-data",
    "iotfleethub",
    "iotsecuretunneling",
    "iotsitewise",
    "iotthingsgraph",
    "iottwinmaker",
    "iotwireless",
    "ivs",
    "kafka",
    "kafkaconnect",
    "kendra",
    "keyspaces",
    "kinesis",
    "kinesis-video-archived-media",
    "kinesis-video-media",
    "kinesis-video-signaling",
    "kinesisanalytics",
    "kinesisanalyticsv2",
    "kinesisvideo",
    "kms",
    "lakeformation",
    "lambda",
    "lex-models",
    "lex-runtime",
    "lexv2-models",
    "lexv2-runtime",
    "license-manager",
    "lightsail",
    "location",
    "logs",
    "lookoutequipment",
    "lookoutmetrics",
    "lookoutvision",
    "machinelearning",
    "macie",
    "macie2",
    "managedblockchain",
    "marketplace-catalog",
    "marketplace-entitlement",
    "marketplacecommerceanalytics",
    "mediaconnect",
    "mediaconvert",
    "medialive",
    "mediapackage",
    "mediapackage-vod",
    "mediastore",
    "mediastore-data",
    "mediatailor",
    "memorydb",
    "meteringmarketplace",
    "mgh",
    "mgn",
    "migration-hub-refactor-spaces",
    "migrationhub-config",
    "migrationhubstrategy",
    "mobile",
    "mq",
    "mturk",
    "mwaa",
    "neptune",
    "network-firewall",
    "networkmanager",
    "nimble",
    "opensearch",
    "opsworks",
    "opsworkscm",
    "organizations",
    "outposts",
    "panorama",
    "personalize",
    "personalize-events",
    "personalize-runtime",
    "pi",
    "pinpoint",
    "pinpoint-email",
    "pinpoint-sms-voice",
    "polly",
    "pricing",
    "proton",
    "qldb",
    "qldb-session",
    "quicksight",
    "ram",
    "rbin",
    "rds",
    "rds-data",
    "redshift",
    "redshift-data",
    "rekognition",
    "resiliencehub",
    "resource-groups",
    "resourcegroupstaggingapi",
    "robomaker",
    "route53",
    "route53-recovery-cluster",
    "route53-recovery-control-config",
    "route53-recovery-readiness",
    "route53domains",
    "route53resolver",
    "rum",
    "s3",
    "s3control",
    "s3outposts",
    "sagemaker",
    "sagemaker-a2i-runtime",
    "sagemaker-edge",
    "sagemaker-featurestore-runtime",
    "sagemaker-runtime",
    "savingsplans",
    "schemas",
    "sdb",
    "secretsmanager",
    "securityhub",
    "serverlessrepo",
    "service-quotas",
    "servicecatalog",
    "servicecatalog-appregistry",
    "servicediscovery",
    "ses",
    "sesv2",
    "shield",
    "signer",
    "sms",
    "sms-voice",
    "snow-device-management",
    "snowball",
    "sns",
    "sqs",
    "ssm",
    "ssm-contacts",
    "ssm-incidents",
    "sso",
    "sso-admin",
    "sso-oidc",
    "stepfunctions",
    "storagegateway",
    "sts",
    "support",
    "swf",
    "synthetics",
    "textract",
    "timestream-query",
    "timestream-write",
    "transcribe",
    "transfer",
    "translate",
    "voice-id",
    "waf",
    "waf-regional",
    "wafv2",
    "wellarchitected",
    "wisdom",
    "workdocs",
    "worklink",
    "workmail",
    "workmailmessageflow",
    "workspaces",
    "workspaces-web",
    "xray",
]
ResourceServiceName = Literal[
    "cloudformation",
    "cloudwatch",
    "dynamodb",
    "ec2",
    "glacier",
    "iam",
    "opsworks",
    "s3",
    "sns",
    "sqs",
]
PaginatorName = Literal[
    "get_offering_status",
    "list_artifacts",
    "list_device_instances",
    "list_device_pools",
    "list_devices",
    "list_instance_profiles",
    "list_jobs",
    "list_network_profiles",
    "list_offering_promotions",
    "list_offering_transactions",
    "list_offerings",
    "list_projects",
    "list_remote_access_sessions",
    "list_runs",
    "list_samples",
    "list_suites",
    "list_tests",
    "list_unique_problems",
    "list_uploads",
    "list_vpce_configurations",
]
RegionName = Literal["us-west-2"]
